smipoly package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   smipoly.smip

Module contents
---------------

.. automodule:: smipoly
   :members:
   :show-inheritance:
   :undoc-members:
